searchData={"items":[{"type":"module","title":"Antenna","doc":"`Antenna` is a mixture of `Phoenix.PubSub` and \n  [`:gen_event`](https://www.erlang.org/doc/apps/stdlib/gen_event.html)\n  functionality with some batteries included.\n\nIt implements back-pressure on top of `GenStage`, is fully conformant with\n  [OTP Design Principles](https://www.erlang.org/doc/system/events). and\n  is distributed out of the box.\n\nOne can have as many isolated `Antenna`s as necessary, distinguished by `t:id()`.\n\nThe workflow looks like shown below.","ref":"Antenna.html"},{"type":"module","title":"Sequence Diagram - Antenna","doc":"```mermaid\nsequenceDiagram\n  Consumer->>+Broadcaster: event(channel, event)\n  Broadcaster-->>+Consumer@Node1: event\n  Broadcaster-->>+Consumer@Node2: event\n  Broadcaster-->>+Consumer@NodeN: event\n  Consumer@Node1-->>-NoOp: mine?\n  Consumer@NodeN-->>-NoOp: mine?\n  Consumer@Node2->>Matchers: event\n  Matchers->>Handlers: handle_match/2\n```\n\n[ASCII representation](https://cascii.app/4164d).","ref":"Antenna.html#module-sequence-diagram"},{"type":"module","title":"Usage Example - Antenna","doc":"The consumer of this library is supposed to declare one or more matchers, subscribing to one\n  or more channels, and then call `Antenna.event/2` to propagate the event.\n\n```elixir\nassert {:ok, _pid, \"{:tag_1, a, _} when is_nil(a)\"} =\n  Antenna.match(Antenna, {:tag_1, a, _} when is_nil(a), self(), channels: [:chan_1])\n\nassert :ok = Antenna.event(Antenna, [:chan_1], {:tag_1, nil, 42})\nassert_receive {:antenna_event, :chan_1, {:tag_1, nil, 42}}\n```","ref":"Antenna.html#module-usage-example"},{"type":"type","title":"Antenna.channel/0","doc":"The identifier of the channel, messages can be sent to, preferrably `atom()`","ref":"Antenna.html#t:channel/0"},{"type":"type","title":"Antenna.event/0","doc":"The event being sent to the listeners","ref":"Antenna.html#t:event/0"},{"type":"function","title":"Antenna.event/3","doc":"Sends an event to all the associated matchers through channels.\n\nThe special `:*` might be specified as channels, then the event\n  will be sent to all the registered channels.","ref":"Antenna.html#event/3"},{"type":"type","title":"Antenna.handler/0","doc":"The actual handler to be associated with an event(s). It might be either a function\n  or a process id, in which case the message of a following shape will be sent to it.\n\n```elixir\n{:antenna_event, channel, event}\n```","ref":"Antenna.html#t:handler/0"},{"type":"type","title":"Antenna.id/0","doc":"The identifier of the isolated `Antenna`","ref":"Antenna.html#t:id/0"},{"type":"macro","title":"Antenna.match/4","doc":"Declares a matcher for tagged events.","ref":"Antenna.html#match/4"},{"type":"macro","title":"Example - Antenna.match/4","doc":"```elixir\nAntenna.match(Antenna, %{tag: _, success: false}, fn channel, message ->\n  Logger.warning(\"The processing failed for [\" <> \n    inspect(channel) <> \"], result: \" <> inspect(message))\nend, channels: [:rabbit])\n```","ref":"Antenna.html#match/4-example"},{"type":"function","title":"Antenna.registered_matchers/1","doc":"Returns a map of matches to matchers","ref":"Antenna.html#registered_matchers/1"},{"type":"function","title":"Antenna.subscribe/3","doc":"Subscribes a matcher process specified by `pid` to a channel(s)","ref":"Antenna.html#subscribe/3"},{"type":"macro","title":"Antenna.unmatch/2","doc":"Undeclares a matcher for tagged events previously declared with `Antenna.match/4`.\n\nAccepts both an original match _or_ a name returned by `Antenna.match/4`,\n  which is effectively `Macro.to_string(match)`.","ref":"Antenna.html#unmatch/2"},{"type":"macro","title":"Example - Antenna.unmatch/2","doc":"```elixir\nAntenna.unmatch(Antenna, %{tag: _, success: false})\n```","ref":"Antenna.html#unmatch/2-example"},{"type":"function","title":"Antenna.unsubscribe/3","doc":"Unsubscribes a previously subscribed matcher process specified by `pid` from the channel(s)","ref":"Antenna.html#unsubscribe/3"},{"type":"behaviour","title":"Antenna.Matcher","doc":"The behaviour defining matchers in the `Antenna` pub-sub model.\n\nWhile the matcher might be a simple function, or a process identifier,\n  using this behaviour would have your testing process simplified.","ref":"Antenna.Matcher.html"},{"type":"function","title":"Antenna.Matcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Antenna.Matcher.html#child_spec/1"},{"type":"callback","title":"Antenna.Matcher.handle_match/2","doc":"The funcion to be called back upon match","ref":"Antenna.Matcher.html#c:handle_match/2"},{"type":"type","title":"Antenna.Matcher.t/0","doc":"The module implementing `handle_match/2` callback","ref":"Antenna.Matcher.html#t:t/0"},{"type":"extras","title":"Antenna","doc":"# Antenna\n\n**TODO: Add description**","ref":"readme.html"},{"type":"extras","title":"Installation - Antenna","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `antenna` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:antenna, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"},"content_type":"text/markdown"}